==> paraview-5.9.1-5-x86_64.pkg.tar.zst: usr/lib/cmake/paraview/GenericIOReader-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::CommonExecutionModel;VTK::ParallelCore;VTK::ParallelMPI")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_private_depends" "")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_library_name" "vtkGenericIOReader")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkGenIOReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkGenericIOReaderModule.h")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/GenericIOReader/vtk/hierarchy/GenericIOReader/vtkGenericIOReader-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> paraview-6.0.1-7-x86_64.pkg.tar.zst: usr/lib/cmake/paraview/GenericIOReader-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::CommonExecutionModel;VTK::ParallelCore;VTK::ParallelMPI")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_private_depends" "")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_library_name" "vtkGenericIOReader")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkGenIOReader.h")
set_property(TARGET "GenericIOReader::vtkGenericIOReader" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/GenericIOReader/vtk/hierarchy/GenericIOReader/vtkGenericIOReader-hierarchy.txt")
unset(_vtk_module_import_prefix)
